@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -19,7 +18,9 @@
 import time
 
 # external packages
-from PyQt5.QtGui import QTextCursor, QColor, QFont
+from PyQt5.QtGui import QColor, QFont
+from PyQt5.QtWidgets import QTableWidgetItem
+from PyQt5.QtCore import Qt
 
 # local import
 from gui.utilities import toolsQtWidget
@@ -52,26 +53,21 @@ class MessageWindow(toolsQtWidget.MWidget):
         if 'messageW' not in self.app.config:
             self.app.config['messageW'] = {}
         config = self.app.config['messageW']
-        height = config.get('height', 600)
-        width = 800
-        self.resize(width, height)
-        x = config.get('winPosX', 0)
-        y = config.get('winPosY', 0)
-        if x > self.screenSizeX - width:
-            x = 0
-        if y > self.screenSizeY - height:
-            y = 0
-        if x != 0 and y != 0:
-            self.move(x, y)
+
+        self.positionWindow(config)
         return True
 
     def storeConfig(self):
         """
         :return: True for test purpose
         """
-        if 'messageW' not in self.app.config:
-            self.app.config['messageW'] = {}
-        config = self.app.config['messageW']
+        config = self.app.config
+        if 'messageW' not in config:
+            config['messageW'] = {}
+        else:
+            config['messageW'].clear()
+        config = config['messageW']
+
         config['winPosX'] = max(self.pos().x(), 0)
         config['winPosY'] = max(self.pos().y(), 0)
         config['height'] = self.height()
@@ -83,19 +79,23 @@ class MessageWindow(toolsQtWidget.MWidget):
         :return:
         """
         self.storeConfig()
-        self.ui.clear.clicked.disconnect(self.clearWindow)
-        self.app.update1s.disconnect(self.writeMessage)
-        self.app.colorChange.disconnect(self.colorChange)
         super().closeEvent(closeEvent)
 
-    def showWindow(self):
+    def clearMessageTable(self):
         """
-        :return: true for test purpose
+        :return:
         """
-        self.ui.clear.clicked.connect(self.clearWindow)
-        self.app.update1s.connect(self.writeMessage)
-        self.app.colorChange.connect(self.colorChange)
-        self.show()
+        mesTab = self.ui.messageTable
+        mesTab.setRowCount(0)
+        mesTab.setColumnCount(4)
+        hl = [' Time', ' Source', ' Type', 'Message / Value']
+        mesTab.setHorizontalHeaderLabels(hl)
+        mesTab.setColumnWidth(0, 65)
+        mesTab.setColumnWidth(1, 85)
+        mesTab.setColumnWidth(2, 135)
+        mesTab.horizontalHeader().setDefaultAlignment(Qt.AlignLeft)
+        mesTab.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
+        mesTab.verticalHeader().setDefaultSectionSize(16)
         return True
 
     def setupMessage(self):
@@ -107,10 +107,11 @@ class MessageWindow(toolsQtWidget.MWidget):
                           QColor(self.M_YELLOW),
                           QColor(self.M_RED),
                           ]
-        self.messFont = [QFont.Normal,
-                         QFont.Bold,
-                         QFont.Normal,
-                         QFont.Normal,
+        fontFam = self.window().font().family()
+        self.messFont = [QFont(fontFam, weight=QFont.Normal),
+                         QFont(fontFam, weight=QFont.Bold),
+                         QFont(fontFam, weight=QFont.Normal),
+                         QFont(fontFam, weight=QFont.Normal),
                          ]
         return True
 
@@ -120,27 +121,20 @@ class MessageWindow(toolsQtWidget.MWidget):
         """
         self.setStyleSheet(self.mw4Style)
         self.setupMessage()
-        self.clearWindow()
+        self.clearMessageTable()
         return True
 
-    def clearWindow(self):
+    def showWindow(self):
         """
         :return: true for test purpose
         """
-        self.ui.message.clear()
+        self.ui.clear.clicked.connect(self.clearMessageTable)
+        self.clearMessageTable()
+        self.app.update1s.connect(self.writeMessage)
+        self.app.colorChange.connect(self.colorChange)
+        self.show()
         return True
 
-    @staticmethod
-    def splitByN(seq, n):
-        """
-        A generator to divide a sequence into chunks of n units.
-        :param n:
-        :return:
-        """
-        while seq:
-            yield seq[:n]
-            seq = seq[n:]
-
     def writeMessage(self):
         """
         writeMessage takes singles with message and writes them to the text
@@ -154,24 +148,37 @@ class MessageWindow(toolsQtWidget.MWidget):
         :return: true for test purpose
         """
         while not self.app.messageQueue.empty():
-            message, mType = self.app.messageQueue.get()
+            prio, source, mType, message = self.app.messageQueue.get()
 
-            withoutPrefix = mType & 0x100
-            mType = mType % 256
+            row = self.ui.messageTable.rowCount()
+            self.ui.messageTable.insertRow(row)
+            timePrefix = time.strftime('%H:%M:%S', time.localtime())
 
-            if mType > len(self.messColor):
-                continue
+            if source:
+                item = QTableWidgetItem(f'{timePrefix}')
+                item.setTextAlignment(Qt.AlignLeft | Qt.AlignVCenter)
+                item.setForeground(self.messColor[prio])
+                item.setFont(self.messFont[prio])
+                self.ui.messageTable.setItem(row, 0, item)
 
-            if withoutPrefix:
-                prefix = ' ' * 9
-            else:
-                prefix = time.strftime('%H:%M:%S ', time.localtime())
+            item = QTableWidgetItem(f'{source}')
+            item.setTextAlignment(Qt.AlignLeft | Qt.AlignVCenter)
+            item.setFont(self.messFont[prio])
+            item.setForeground(self.messColor[prio])
+            self.ui.messageTable.setItem(row, 1, item)
 
-            self.ui.message.setTextColor(self.messColor[mType])
-            self.ui.message.setFontWeight(self.messFont[mType])
+            item = QTableWidgetItem(f'{mType}')
+            item.setTextAlignment(Qt.AlignLeft | Qt.AlignVCenter)
+            item.setFont(self.messFont[prio])
+            item.setForeground(self.messColor[prio])
+            self.ui.messageTable.setItem(row, 2, item)
 
-            for line in self.splitByN(message, 87):
-                self.ui.message.insertPlainText(prefix + line + '\n')
-            self.ui.message.moveCursor(QTextCursor.End)
+            item = QTableWidgetItem(f'{message}')
+            item.setTextAlignment(Qt.AlignLeft | Qt.AlignVCenter)
+            item.setFont(self.messFont[prio])
+            item.setForeground(self.messColor[prio])
+            self.ui.messageTable.setItem(row, 3, item)
+
+            self.ui.messageTable.scrollToBottom()
 
         return True
