@@ -61,8 +61,8 @@ from gui.mainWmixin.tabAnalysis import Analysis
 from gui.mainWmixin.tabPower import Power
 from gui.mainWmixin.tabSettDevice import SettDevice
 from gui.mainWmixin.tabSettMount import SettMount
-from gui.mainWmixin.tabSettImaging import SettImaging
-from gui.mainWmixin.tabSettImageStats import SettImageStats
+from gui.mainWmixin.tabImage_Manage import ImageManage
+from gui.mainWmixin.tabImage_Stats import ImagsStats
 from gui.mainWmixin.tabSettDome import SettDome
 from gui.mainWmixin.tabSettParkPos import SettParkPos
 from gui.mainWmixin.tabSettRelay import SettRelay
@@ -89,8 +89,8 @@ class MainWindow(
     Analysis,
     SettDevice,
     SettMount,
-    SettImaging,
-    SettImageStats,
+    ImageManage,
+    ImagsStats,
     SettDome,
     SettParkPos,
     SettRelay,
@@ -410,6 +410,7 @@ class MainWindow(
         # minor planets
         self.wIcon(self.ui.progMinorPlanetsFull, 'run')
         self.wIcon(self.ui.progMinorPlanetsFiltered, 'run')
+        self.wIcon(self.ui.progMinorPlanetsSelected, 'run')
         self.wIcon(self.ui.progEarthRotationData, 'run')
         self.wIcon(self.ui.downloadIERS, 'run')
 
@@ -535,6 +536,8 @@ class MainWindow(
         pixmap = pixmap.transformed(QTransform().rotate(-90))
         pixmap = pixmap.scaled(37, 128, 1)
         self.ui.meteoblueIcon.setPixmap(pixmap)
+        self.ui.meteoblueIcon.setVisible(False)
+        self.ui.meteoblueSeeing.setVisible(False)
         return True
 
     def updateMountConnStat(self, status):
