@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -35,31 +34,7 @@ class FocuserIndi(IndiClass):
 
     def __init__(self, app=None, signals=None, data=None):
         self.signals = signals
-        super().__init__(app=app, data=data, threadPool=app.threadPool)
-        self.data = data
-
-    def setUpdateConfig(self, deviceName):
-        """
-        _setUpdateRate corrects the update rate of weather devices to get an defined
-        setting regardless, what is setup in server side.
-
-        :param deviceName:
-        :return: success
-        """
-        if deviceName != self.deviceName:
-            return False
-        if self.device is None:
-            return False
-
-        update = self.device.getNumber('PERIOD_MS')
-        if update.get('PERIOD', 0) == self.UPDATE_RATE:
-            return True
-
-        update['PERIOD'] = self.UPDATE_RATE
-        suc = self.client.sendNewNumber(deviceName=deviceName,
-                                        propertyName='PERIOD_MS',
-                                        elements=update)
-        return suc
+        super().__init__(app=app, data=data)
 
     def move(self, position=None):
         """
